@@ -6,7 +6,7 @@
     'name_es_CO': 'País',
     'name_es_ES': 'País',
     'name_fr_FR': 'Pays',
-    'version' : '1.6.0',
+    'version' : '1.8.0',
     'author' : 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -20,9 +20,11 @@
         'country.xml',
     ],
     'translation': [
+        'cs_CZ.csv',
         'de_DE.csv',
         'es_CO.csv',
         'es_ES.csv',
         'fr_FR.csv',
+        'ru_RU.csv',
    ],
 }
